# Test Command Template

    python3 -m doctest -v -o ELLIPSIS easy_pandas.py



# Example Package




This is a simple example package. You can use
[GitHub-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.
